==> zio-aws-s3control_2.12-7.21.15.12-sources.jar: zio/aws/s3control/model/GetMultiRegionAccessPointPolicyRequest.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.s3control.model.primitives.{
  MultiRegionAccessPointName,
  AccountId
}
import scala.jdk.CollectionConverters._
final case class GetMultiRegionAccessPointPolicyRequest(
    accountId: AccountId,
    name: MultiRegionAccessPointName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest = {
    import GetMultiRegionAccessPointPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
      .builder()
      .accountId(AccountId.unwrap(accountId): java.lang.String)
      .name(MultiRegionAccessPointName.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest.ReadOnly =
    zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest
      .wrap(buildAwsValue())
}
object GetMultiRegionAccessPointPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest =
      zio.aws.s3control.model
        .GetMultiRegionAccessPointPolicyRequest(accountId, name)
    def accountId: AccountId
    def name: MultiRegionAccessPointName
    def getAccountId: ZIO[Any, Nothing, AccountId] = ZIO.succeed(accountId)
    def getName: ZIO[Any, Nothing, MultiRegionAccessPointName] =
      ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
  ) extends zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest.ReadOnly {
    override val accountId: AccountId =
      zio.aws.s3control.model.primitives.AccountId(impl.accountId())
    override val name: MultiRegionAccessPointName =
      zio.aws.s3control.model.primitives.MultiRegionAccessPointName(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
  ): zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-s3control_3-5.17.295.16-sources.jar: zio/aws/s3control/model/GetMultiRegionAccessPointPolicyRequest.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.s3control.model.primitives.{
  MultiRegionAccessPointName,
  AccountId
}
import scala.jdk.CollectionConverters.*
final case class GetMultiRegionAccessPointPolicyRequest(
    accountId: AccountId,
    name: MultiRegionAccessPointName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest = {
    import GetMultiRegionAccessPointPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
      .builder()
      .accountId(AccountId.unwrap(accountId): java.lang.String)
      .name(MultiRegionAccessPointName.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest.ReadOnly =
    zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest
      .wrap(buildAwsValue())
}
object GetMultiRegionAccessPointPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest =
      zio.aws.s3control.model
        .GetMultiRegionAccessPointPolicyRequest(accountId, name)
    def accountId: AccountId
    def name: MultiRegionAccessPointName
    def getAccountId: ZIO[Any, Nothing, AccountId] = ZIO.succeed(accountId)
    def getName: ZIO[Any, Nothing, MultiRegionAccessPointName] =
      ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
  ) extends zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest.ReadOnly {
    override val accountId: AccountId =
      zio.aws.s3control.model.primitives.AccountId(impl.accountId())
    override val name: MultiRegionAccessPointName =
      zio.aws.s3control.model.primitives.MultiRegionAccessPointName(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.GetMultiRegionAccessPointPolicyRequest
  ): zio.aws.s3control.model.GetMultiRegionAccessPointPolicyRequest.ReadOnly =
    new Wrapper(impl)
}
